/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Joe Hewitt <hewitt@netscape.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

/* ===== console.css ====================================================
   == Styles used by the JavaScript Console window.
   ====================================================================== */

@namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul");

.console-box {
  background-color: -moz-Field;
  color: -moz-FieldText;
}

/* ::::: console rows ::::: */

.console-row {
  border-bottom: 2px solid -moz-FieldText;
  padding: 0px;
}

.console-row-icon {
  border-right: 1px solid ThreeDShadow;
  padding: 5px;
  background-color: -moz-Dialog;
  -moz-box-align: start !important;
}

.console-icon {
  list-style-image: inherit;
}

/* ..... error rows ..... */

.console-row-code {
  padding: 3px 0px 3px 3px;
  color: #0000BB;
  font-size: larger;
}

.console-dots,
.console-caret {
  height: 9px;
}

.console-dots {
  background: url("chrome://global/skin/console/console-error-dash.gif") repeat-x top;
}

.console-caret {
  width: 7px;
  background: url("chrome://global/skin/console/console-error-caret.gif") no-repeat top;
}

/* ..... message rows ..... */

.console-row[type="message"] {
  font-family: monospace;
}

/* ..... selected state ..... */

.console-row[selected="true"] {
  background-color: #B7DBEB !important;
}

.console-row-code[selected="true"],
.console-row-content[selected="true"] > .console-row-file > .console-error-source > .text-link {
  color: inherit !important;
}

/* ::::: icons ::::: */

.console-row[type="error"],
.console-row[type="exception"] {
  list-style-image: url("chrome://global/skin/icons/Error.png");
}

.console-row[type="warning"] {
  list-style-image: url("chrome://global/skin/icons/Warning.png");
}

.console-row[type="message"] {
  list-style-image: url("chrome://global/skin/icons/Message.png");
}

/* ::::: toolbars ::::: */

#TextboxEval {
  margin: 2px !important;
}

toolbarseparator {
  min-height: 1em;
}


/* Toolbar icons */

.toolbarbutton-text {
  margin-left: 4px !important;
} 

toolbar#ToolbarMode toolbarbutton {
  list-style-image: url("chrome://global/skin/console/Console-toolbar.png");
}

toolbarbutton[observes="Console:modeAll"] {
  -moz-image-region: rect(0px, 16px, 16px, 0px);
}
toolbarbutton[observes="Console:modeAll"]:hover,
toolbarbutton[observes="Console:modeAll"][checked="true"] {
  -moz-image-region: rect(16px, 16px, 32px, 0px);
}

toolbarbutton[observes="Console:modeErrors"] {
  -moz-image-region: rect(0px, 32px, 16px, 16px);
}
toolbarbutton[observes="Console:modeErrors"]:hover,
toolbarbutton[observes="Console:modeErrors"][checked="true"] {
  -moz-image-region: rect(16px, 32px, 32px, 16px);
}

toolbarbutton[observes="Console:modeWarnings"] {
  -moz-image-region: rect(0px, 48px, 16px, 32px);
}
toolbarbutton[observes="Console:modeWarnings"]:hover,
toolbarbutton[observes="Console:modeWarnings"][checked="true"] {
  -moz-image-region: rect(16px, 48px, 32px, 32px);
}

toolbarbutton[observes="Console:modeMessages"] {
  -moz-image-region: rect(0px, 64px, 16px, 48px);
}
toolbarbutton[observes="Console:modeMessages"]:hover,
toolbarbutton[observes="Console:modeMessages"][checked="true"] {
  -moz-image-region: rect(16px, 64px, 32px, 48px);
}

toolbarbutton[observes="Console:clear"] {
  -moz-image-region: rect(0px, 80px, 16px, 64px);
}
toolbarbutton[observes="Console:clear"]:hover,
toolbarbutton[observes="Console:clear"][checked="true"] {
  -moz-image-region: rect(16px, 80px, 32px, 64px);
}
