//Microsoft Developer Studio generated resource script.
//
#include "resource.h"

#define APSTUDIO_READONLY_SYMBOLS
/////////////////////////////////////////////////////////////////////////////
//
// Generated from the TEXTINCLUDE 2 resource.
//
#include "afxres.h"

/////////////////////////////////////////////////////////////////////////////
#undef APSTUDIO_READONLY_SYMBOLS

/////////////////////////////////////////////////////////////////////////////
// English (U.S.) resources

#if !defined(AFX_RESOURCE_DLL) || defined(AFX_TARG_ENU)
#ifdef _WIN32
LANGUAGE LANG_ENGLISH, SUBLANG_ENGLISH_US
#pragma code_page(1252)
#endif //_WIN32

#ifdef APSTUDIO_INVOKED
/////////////////////////////////////////////////////////////////////////////
//
// TEXTINCLUDE
//

1 TEXTINCLUDE DISCARDABLE 
BEGIN
    "resource.h\0"
END

2 TEXTINCLUDE DISCARDABLE 
BEGIN
    "#include ""afxres.h""\r\n"
    "\0"
END

3 TEXTINCLUDE DISCARDABLE 
BEGIN
    "#define _AFX_NO_SPLITTER_RESOURCES\r\n"
    "#define _AFX_NO_OLE_RESOURCES\r\n"
    "#define _AFX_NO_TRACKER_RESOURCES\r\n"
    "#define _AFX_NO_PROPERTY_RESOURCES\r\n"
    "\r\n"
    "#if !defined(AFX_RESOURCE_DLL) || defined(AFX_TARG_ENU)\r\n"
    "#ifdef _WIN32\r\n"
    "LANGUAGE 9, 1\r\n"
    "#pragma code_page(1252)\r\n"
    "#endif //_WIN32\r\n"
    "#include ""res\\mfcembed.rc2""  // non-Microsoft Visual C++ edited resources\r\n"
    "#include ""afxres.rc""         // Standard components\r\n"
    "#endif\r\n"
    "\0"
END

#endif    // APSTUDIO_INVOKED


/////////////////////////////////////////////////////////////////////////////
//
// Icon
//

// Icon with lowest ID value placed first to ensure application icon
// remains consistent on all systems.
IDR_MAINFRAME           ICON    DISCARDABLE     "res\\mfcembed.ico"
IDR_SECURITY_LOCK       ICON    DISCARDABLE     "res\\ssecur.ico"
IDR_SECURITY_UNLOCK     ICON    DISCARDABLE     "res\\sinsecur.ico"
IDR_SECURITY_BROKEN     ICON    DISCARDABLE     "res\\broken.ico"

/////////////////////////////////////////////////////////////////////////////
//
// Bitmap
//

IDR_MAINFRAME           BITMAP  MOVEABLE PURE   "res\\Toolbar.bmp"
IDR_EDITOR              BITMAP  MOVEABLE PURE   "res\\mainfram.bmp"

/////////////////////////////////////////////////////////////////////////////
//
// Toolbar
//

IDR_MAINFRAME TOOLBAR DISCARDABLE  20, 18
BEGIN
    BUTTON      ID_NAV_BACK
    BUTTON      ID_NAV_FORWARD
    SEPARATOR
    BUTTON      ID_NAV_RELOAD
    BUTTON      ID_NAV_STOP
    SEPARATOR
    BUTTON      ID_NAV_HOME
    SEPARATOR
    BUTTON      ID_APP_ABOUT
END

IDR_EDITOR TOOLBAR DISCARDABLE  20, 18
BEGIN
    BUTTON      ID_BOLD
    BUTTON      ID_ITALICS
    BUTTON      ID_UNDERLINE
    SEPARATOR
    BUTTON      ID_INDENT
    BUTTON      ID_OUTDENT
    SEPARATOR
    BUTTON      ID_FONTBLACK
    BUTTON      ID_FONTRED
    BUTTON      ID_BGCOLOR
    BUTTON      ID_NOBGCOLOR
    SEPARATOR
    BUTTON      ID_FONTSIZEINCREASE
    BUTTON      ID_FONTSIZEDECREASE
    SEPARATOR
    BUTTON      ID_ALIGNLEFT
    BUTTON      ID_ALIGNCENTER
    BUTTON      ID_ALIGNRIGHT
    SEPARATOR
    BUTTON      ID_INSERTLINK
END


/////////////////////////////////////////////////////////////////////////////
//
// Menu
//

IDR_MAINFRAME MENU PRELOAD DISCARDABLE 
BEGIN
    POPUP "&File"
    BEGIN
        MENUITEM "&New Browser Window\tCtrl+N", ID_NEW_BROWSER
        MENUITEM "New &Editor Window",          ID_NEW_EDITORWINDOW
        MENUITEM SEPARATOR
        MENUITEM "&Open File...\tCtrl+O",       ID_FILE_OPEN
        MENUITEM "&Save Page As...\tCtrl+S",    ID_FILE_SAVE_AS
        MENUITEM SEPARATOR
        MENUITEM "Page Set&up...",              ID_FILE_PRINTSETUP
        MENUITEM "&Print...\tCtrl-P",           ID_FILE_PRINT
        MENUITEM "Print Pre&view",              ID_FILE_PRINTPREVIEW
        MENUITEM SEPARATOR
        MENUITEM "E&xit",                       ID_APP_EXIT
    END
    POPUP "&Edit"
    BEGIN
        MENUITEM "Cu&t\tCtrl+X",                ID_EDIT_CUT
        MENUITEM "&Copy\tCtrl+C",               ID_EDIT_COPY
        MENUITEM "&Paste\tCtrl+V",              ID_EDIT_PASTE
        MENUITEM SEPARATOR
        MENUITEM "Select &All",                 ID_EDIT_SELECT_ALL
        MENUITEM "Select &None",                ID_EDIT_SELECT_NONE
        MENUITEM SEPARATOR
        MENUITEM "&Find in This Page...\tCtrl+F", ID_EDIT_FIND
        MENUITEM SEPARATOR
        MENUITEM "Profiles...",                 ID_MANAGE_PROFILES
        MENUITEM SEPARATOR
        MENUITEM "Preferences...",              ID_EDIT_PREFERENCES
    END
    POPUP "&View"
    BEGIN
        MENUITEM "Page S&ource",                ID_VIEW_SOURCE
        MENUITEM "Page &Info",                  ID_VIEW_INFO
        MENUITEM SEPARATOR
        MENUITEM "&Toolbar",                    ID_VIEW_TOOLBAR
        MENUITEM "&Status Bar",                 ID_VIEW_STATUS_BAR
    END
    POPUP "&Go"
    BEGIN
        MENUITEM "&Back",                       ID_NAV_BACK
        MENUITEM "&Forward",                    ID_NAV_FORWARD
        MENUITEM "&Home",                       ID_NAV_HOME
    END
    POPUP "&Help"
    BEGIN
        MENUITEM "&About MfcEmbed...",          ID_APP_ABOUT
    END
END

IDR_CTXMENU_DOCUMENT MENU DISCARDABLE 
BEGIN
    POPUP "Document Context Menu"
    BEGIN
        MENUITEM "&Back",                       ID_NAV_BACK
        MENUITEM "&Forward",                    ID_NAV_FORWARD
        MENUITEM "&Reload",                     ID_NAV_RELOAD
        MENUITEM "&Stop",                       ID_NAV_STOP
        MENUITEM SEPARATOR
        MENUITEM "&View Page Source",           ID_VIEW_SOURCE
        MENUITEM "View Page &Info",             ID_VIEW_INFO
        MENUITEM "View Background &Image",      ID_VIEW_IMAGE
        MENUITEM SEPARATOR
        MENUITEM "Save &Page As...",            ID_FILE_SAVE_AS
        MENUITEM SEPARATOR
        MENUITEM "Select &All",                 ID_EDIT_SELECT_ALL
        MENUITEM "Select &None",                ID_EDIT_SELECT_NONE
        MENUITEM "&Copy",                       ID_EDIT_COPY
        MENUITEM "&Paste",                      ID_EDIT_PASTE
    END
END

IDR_CTXMENU_IMAGE MENU DISCARDABLE 
BEGIN
    POPUP "Image Context Menu"
    BEGIN
        MENUITEM "&Back",                       ID_NAV_BACK
        MENUITEM "&Forward",                    ID_NAV_FORWARD
        MENUITEM "&Reload",                     ID_NAV_RELOAD
        MENUITEM "&Stop",                       ID_NAV_STOP
        MENUITEM SEPARATOR
        MENUITEM "&View Page Source",           ID_VIEW_SOURCE
        MENUITEM "View &Image",                 ID_VIEW_IMAGE
        MENUITEM SEPARATOR
        MENUITEM "Save Image As...",            ID_SAVE_IMAGE_AS
        MENUITEM "Save &Page As...",            ID_FILE_SAVE_AS
    END
END

IDR_CTXMENU_LINK MENU DISCARDABLE 
BEGIN
    POPUP "Link Context Menu"
    BEGIN
        MENUITEM "Open Link In New Window",     ID_OPEN_LINK_IN_NEW_WINDOW
        MENUITEM SEPARATOR
        MENUITEM "&Back",                       ID_NAV_BACK
        MENUITEM "&Forward",                    ID_NAV_FORWARD
        MENUITEM "&Reload",                     ID_NAV_RELOAD
        MENUITEM "&Stop",                       ID_NAV_STOP
        MENUITEM SEPARATOR
        MENUITEM "&View Page Source",           ID_VIEW_SOURCE
        MENUITEM SEPARATOR
        MENUITEM "View &Image",                 ID_VIEW_IMAGE
        MENUITEM SEPARATOR
        MENUITEM "Save &Page As...",            ID_FILE_SAVE_AS
        MENUITEM "Save &Link As...",            ID_SAVE_LINK_AS
        MENUITEM "&Copy Link Location",         ID_COPY_LINK_LOCATION
    END
END

IDR_CTXMENU_TEXT MENU DISCARDABLE 
BEGIN
    POPUP "Selection Context Menu"
    BEGIN
        MENUITEM "Cu&t",                        ID_EDIT_CUT
        MENUITEM "&Copy",                       ID_EDIT_COPY
        MENUITEM "&Paste",                      ID_EDIT_PASTE
        MENUITEM "Select &All",                 ID_EDIT_SELECT_ALL
    END
END

IDR_CTXMENU_EDITOR MENU DISCARDABLE 
BEGIN
    POPUP "Editor Context Menu"
    BEGIN
        MENUITEM "Cu&t",                        ID_EDIT_CUT
        MENUITEM "&Copy",                       ID_EDIT_COPY
        MENUITEM "&Paste",                      ID_EDIT_PASTE
        MENUITEM SEPARATOR
        MENUITEM "Select &All",                 ID_EDIT_SELECT_ALL
        MENUITEM "Select &None",                ID_EDIT_SELECT_NONE
    END
END

IDR_EDITOR MENU PRELOAD DISCARDABLE 
BEGIN
    POPUP "&File"
    BEGIN
        MENUITEM "&New Browser Window\tCtrl+N", ID_NEW_BROWSER
        MENUITEM "New &Editor Window",          ID_NEW_EDITORWINDOW
        MENUITEM SEPARATOR
        MENUITEM "&Open File...\tCtrl+O",       ID_FILE_OPEN
        MENUITEM "&Save Page As...\tCtrl+S",    ID_FILE_SAVE_AS
        MENUITEM SEPARATOR
        MENUITEM "&Print...\tCtrl-P",           ID_FILE_PRINT
        MENUITEM SEPARATOR
        MENUITEM "E&xit\tCtrl+Q",               ID_APP_EXIT
    END
    POPUP "&Edit"
    BEGIN
        MENUITEM "Undo\tCtrl+Z",                ID_EDITOR_UNDO
        MENUITEM "Redo\tCtrl+Shift+Z",          ID_EDITOR_REDO
        MENUITEM SEPARATOR
        MENUITEM "Cu&t\tCtrl+X",                ID_EDIT_CUT
        MENUITEM "&Copy\tCtrl+C",               ID_EDIT_COPY
        MENUITEM "&Paste\tCtrl+V",              ID_EDIT_PASTE
        MENUITEM SEPARATOR
        MENUITEM "Select &All",                 ID_EDIT_SELECT_ALL
        MENUITEM "Select &None",                ID_EDIT_SELECT_NONE
        MENUITEM SEPARATOR
        MENUITEM "&Find in This Page...\tCtrl+F", ID_EDIT_FIND
    END
    POPUP "F& ormat"
    BEGIN
        POPUP "Font"
        BEGIN
            MENUITEM "Arial",                       ID_ARIAL
            MENUITEM "Times New Roman",             ID_TIMES
            MENUITEM "Courier",                     ID_COURIER
        END
    END
    POPUP "&Help"
    BEGIN
        MENUITEM "&About MfcEmbed...",          ID_APP_ABOUT
    END
END


/////////////////////////////////////////////////////////////////////////////
//
// Accelerator
//

IDR_MAINFRAME ACCELERATORS PRELOAD MOVEABLE PURE 
BEGIN
    "C",            ID_EDIT_COPY,           VIRTKEY, CONTROL, NOINVERT
    "F",            ID_EDIT_FIND,           VIRTKEY, CONTROL, NOINVERT
    "N",            ID_NEW_BROWSER,         VIRTKEY, CONTROL, NOINVERT
    "O",            ID_FILE_OPEN,           VIRTKEY, CONTROL, NOINVERT
    "S",            ID_FILE_SAVE_AS,        VIRTKEY, CONTROL, NOINVERT
    "V",            ID_EDIT_PASTE,          VIRTKEY, CONTROL, NOINVERT
    VK_BACK,        ID_EDIT_UNDO,           VIRTKEY, ALT, NOINVERT
    VK_DELETE,      ID_EDIT_CUT,            VIRTKEY, SHIFT, NOINVERT
    VK_ESCAPE,      ID_NAV_STOP,            VIRTKEY, NOINVERT
    VK_F6,          ID_NEXT_PANE,           VIRTKEY, NOINVERT
    VK_F6,          ID_PREV_PANE,           VIRTKEY, SHIFT, NOINVERT
    VK_INSERT,      ID_EDIT_COPY,           VIRTKEY, CONTROL, NOINVERT
    VK_INSERT,      ID_EDIT_PASTE,          VIRTKEY, SHIFT, NOINVERT
    "X",            ID_EDIT_CUT,            VIRTKEY, CONTROL, NOINVERT
    "Z",            ID_EDIT_UNDO,           VIRTKEY, CONTROL, NOINVERT
    "Z",            ID_EDITOR_UNDO,         VIRTKEY, CONTROL, NOINVERT
    "Z",            ID_EDIT_REDO,           VIRTKEY, SHIFT, CONTROL, 
                                                    NOINVERT
    "Z",            ID_EDITOR_REDO,         VIRTKEY, SHIFT, CONTROL, 
                                                    NOINVERT
END


/////////////////////////////////////////////////////////////////////////////
//
// Dialog
//

IDD_ABOUTBOX DIALOG DISCARDABLE  0, 0, 235, 55
STYLE DS_MODALFRAME | WS_POPUP | WS_CAPTION | WS_SYSMENU
CAPTION "About MfcEmbed"
FONT 8, "MS Sans Serif"
BEGIN
    ICON            IDR_MAINFRAME,IDC_STATIC,11,17,20,20
    LTEXT           "Mozilla MfcEmbed Version 1.0",IDC_STATIC,40,10,119,8,
                    SS_NOPREFIX
    LTEXT           "Copyright (C) 2001",IDC_STATIC,40,25,119,8
    DEFPUSHBUTTON   "OK",IDOK,178,7,50,14,WS_GROUP
END

IDD_PROFILES DIALOG DISCARDABLE  0, 0, 193, 110
STYLE DS_MODALFRAME | WS_POPUP | WS_CAPTION | WS_SYSMENU
CAPTION "Manage Profiles"
FONT 8, "MS Sans Serif"
BEGIN
    LISTBOX         IDC_LIST1,7,7,117,56,LBS_NOINTEGRALHEIGHT | WS_VSCROLL | 
                    WS_TABSTOP
    PUSHBUTTON      "New...",IDC_PROF_NEW,133,7,50,14
    PUSHBUTTON      "Rename...",IDC_PROF_RENAME,133,27,50,14
    PUSHBUTTON      "Delete",IDC_PROF_DELETE,133,48,50,14
    CONTROL         "Ask At Startup",IDC_CHECK_ASK_AT_START,"Button",
                    BS_AUTOCHECKBOX | WS_TABSTOP,7,71,61,10
    DEFPUSHBUTTON   "OK",IDOK,77,89,50,14
    PUSHBUTTON      "Cancel",IDCANCEL,133,89,50,14
END

IDD_PROFILE_NEW DIALOG DISCARDABLE  0, 0, 177, 79
STYLE DS_MODALFRAME | WS_POPUP | WS_CAPTION | WS_SYSMENU
CAPTION "New Profile"
FONT 8, "MS Sans Serif"
BEGIN
    RTEXT           "Name:",IDC_STATIC,13,18,22,8
    EDITTEXT        IDC_NEW_PROF_NAME,39,16,122,14,ES_AUTOHSCROLL
    RTEXT           "Locale:",IDC_STATIC,11,37,24,8
    COMBOBOX        IDC_LOCALE_COMBO,39,35,67,30,CBS_DROPDOWNLIST | CBS_SORT | 
                    WS_DISABLED | WS_VSCROLL | WS_TABSTOP
    DEFPUSHBUTTON   "OK",IDOK,64,58,50,14
    PUSHBUTTON      "Cancel",IDCANCEL,120,58,50,14
END

IDD_PROFILE_RENAME DIALOG DISCARDABLE  0, 0, 177, 71
STYLE DS_MODALFRAME | WS_POPUP | WS_CAPTION | WS_SYSMENU
CAPTION "Rename Profile"
FONT 8, "MS Sans Serif"
BEGIN
    RTEXT           "New Name:",IDC_STATIC,7,18,38,8
    EDITTEXT        IDC_NEW_NAME,50,16,113,14,ES_AUTOHSCROLL
    DEFPUSHBUTTON   "OK",IDOK,60,48,50,14
    PUSHBUTTON      "Cancel",IDCANCEL,115,48,50,14
END

IDD_FINDDLG DIALOG DISCARDABLE  30, 73, 239, 83
STYLE DS_MODALFRAME | DS_3DLOOK | DS_CONTEXTHELP | WS_POPUP | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Find"
FONT 8, "MS Shell Dlg"
BEGIN
    LTEXT           "Fi&nd what:",-1,4,8,42,8
    EDITTEXT        IDC_FIND_EDIT,47,7,128,12,ES_AUTOHSCROLL | WS_GROUP
    CONTROL         "Wra&p around",IDC_WRAP_AROUND,"Button",BS_AUTOCHECKBOX | 
                    WS_GROUP | WS_TABSTOP,47,45,65,12
    CONTROL         "Match &case",IDC_MATCH_CASE,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,47,29,64,12
    CONTROL         "Search &backwards",IDC_SEARCH_BACKWARDS,"Button",
                    BS_AUTOCHECKBOX | WS_TABSTOP,47,62,75,12
    DEFPUSHBUTTON   "&Find Next",IDOK,182,5,50,14,WS_GROUP
    PUSHBUTTON      "Cancel",IDCANCEL,182,23,50,14
END

IDD_PREFS_START_PAGE DIALOG DISCARDABLE  0, 0, 284, 150
STYLE WS_CHILD | WS_DISABLED | WS_CAPTION
CAPTION "Startup"
FONT 8, "MS Sans Serif"
BEGIN
    GROUPBOX        "MfcEmbed starts with",IDC_STATIC,6,10,271,49
    CONTROL         "Bla&nk Page",IDC_RADIO_BLANK_PAGE,"Button",
                    BS_AUTORADIOBUTTON | WS_GROUP,16,24,53,10
    CONTROL         "&Home Page",IDC_RADIO_HOME_PAGE,"Button",
                    BS_AUTORADIOBUTTON,16,40,53,10
    GROUPBOX        "Home Page",IDC_STATIC,6,67,271,51
    LTEXT           "Clicking the Home button will take you to this page",
                    IDC_STATIC,17,80,234,8
    LTEXT           "Loc&ation:",IDC_STATIC,17,98,31,8
    EDITTEXT        IDC_EDIT_HOMEPAGE,53,95,211,14,ES_AUTOHSCROLL
END

IDD_PRINTSETUP_DIALOG DIALOG DISCARDABLE  0, 0, 328, 175
STYLE DS_SYSMODAL | DS_MODALFRAME | WS_POPUP | WS_CAPTION | WS_SYSMENU
CAPTION "Page Setup"
FONT 8, "MS Sans Serif"
BEGIN
    DEFPUSHBUTTON   "OK",IDOK,7,154,50,14
    PUSHBUTTON      "Cancel",IDCANCEL,271,154,50,14
    CONTROL         "Tab1",IDC_PRINTSETUP_TAB_CTRL,"SysTabControl32",0x0,7,7,
                    314,125
END

IDD_HEADERFOOTER_TAB DIALOG DISCARDABLE  0, 0, 319, 106
STYLE DS_MODALFRAME | WS_POPUP | WS_CAPTION | WS_SYSMENU
CAPTION "Margins && Headers/Footers"
FONT 8, "MS Sans Serif"
BEGIN
    GROUPBOX        "Headers && Footers",IDC_STATIC,7,38,229,56
    RTEXT           "Left",IDC_STATIC,30,65,13,8
    RTEXT           "Center",IDC_STATIC,104,65,22,8
    RTEXT           "Right",IDC_STATIC,187,65,18,8
    EDITTEXT        IDC_TOP_MARGIN_TXT,39,15,40,14,ES_AUTOHSCROLL
    EDITTEXT        IDC_LEFT_MARGIN_TXT,112,15,40,14,ES_AUTOHSCROLL
    EDITTEXT        IDC_BOTTOM_MARGIN_TXT,185,15,40,14,ES_AUTOHSCROLL
    EDITTEXT        IDC_RIGHT_MARGIN_TXT,258,15,40,14,ES_AUTOHSCROLL
    GROUPBOX        "Margins",IDC_STATIC,7,7,302,26
    LTEXT           "Left:",IDC_STATIC,95,17,15,8
    LTEXT           "Top:",IDC_STATIC,22,17,16,8
    LTEXT           "Right:",IDC_STATIC,236,17,20,8
    LTEXT           "Bottom:",IDC_STATIC,158,17,25,8
    COMBOBOX        IDC_FTR_LEFT_CMBX,13,76,57,70,CBS_DROPDOWNLIST | 
                    WS_VSCROLL | WS_TABSTOP
    COMBOBOX        IDC_FTR_CENTER_CMBX,92,76,57,70,CBS_DROPDOWNLIST | 
                    WS_VSCROLL | WS_TABSTOP
    COMBOBOX        IDC_FTR_RIGHT_CMBX,171,76,57,70,CBS_DROPDOWNLIST | 
                    WS_VSCROLL | WS_TABSTOP
    COMBOBOX        IDC_HDR_LEFT_CMBX,13,49,57,70,CBS_DROPDOWNLIST | 
                    WS_VSCROLL | WS_TABSTOP
    COMBOBOX        IDC_HDR_CENTER_CMBX,92,50,57,70,CBS_DROPDOWNLIST | 
                    WS_VSCROLL | WS_TABSTOP
    COMBOBOX        IDC_HDR_RIGHT_CMBX,171,50,57,70,CBS_DROPDOWNLIST | 
                    WS_VSCROLL | WS_TABSTOP
END

IDD_FORMAT_OPTIONS_TAB DIALOG DISCARDABLE  0, 0, 321, 126
STYLE DS_MODALFRAME | WS_POPUP | WS_CAPTION | WS_SYSMENU
CAPTION "Format && Options"
FONT 8, "MS Sans Serif"
BEGIN
    CONTROL         "&Portait",IDC_PRT_PORTRAIT_RD,"Button",
                    BS_AUTORADIOBUTTON | WS_GROUP,14,16,36,10
    CONTROL         "&Landscape",IDC_PRT_LANDSCAPE_RD,"Button",
                    BS_AUTORADIOBUTTON,56,16,51,10
    COMBOBOX        IDC_PAPER_SIZE_CBX,26,40,81,67,CBS_DROPDOWNLIST | 
                    WS_VSCROLL | WS_GROUP | WS_TABSTOP
    EDITTEXT        IDC_UD_PAPER_WDTH,33,57,40,14,ES_AUTOHSCROLL | 
                    WS_DISABLED
    EDITTEXT        IDC_UD_PAPER_HGT,106,57,40,14,ES_AUTOHSCROLL | 
                    WS_DISABLED
    CONTROL         "Inches",IDC_INCHES_RD,"Button",BS_AUTORADIOBUTTON | 
                    WS_DISABLED | WS_GROUP,13,76,37,10
    CONTROL         "Millimeters",IDC_MILLI_RD,"Button",BS_AUTORADIOBUTTON | 
                    WS_DISABLED,53,76,48,10
    CONTROL         "Slider1",IDC_SCALE,"msctls_trackbar32",TBS_AUTOTICKS | 
                    TBS_BOTH | WS_TABSTOP,163,42,100,19
    EDITTEXT        IDC_SCALE_TXT,264,47,19,14,ES_AUTOHSCROLL
    CONTROL         "Print Background C&olors",IDC_PRT_BGCOLORS,"Button",
                    BS_AUTOCHECKBOX | WS_TABSTOP,10,100,92,10
    CONTROL         "Print Background &Images",IDC_PRT_BGIMAGES,"Button",
                    BS_AUTOCHECKBOX | WS_TABSTOP,124,100,95,10
    GROUPBOX        "Scaling",IDC_STATIC,161,31,148,34
    LTEXT           "Size:",IDC_STATIC,10,41,16,8
    GROUPBOX        "Format",IDC_STATIC,7,31,147,57
    LTEXT           "Width:",IDC_UD_WIDTH_LBL,10,60,22,8,WS_DISABLED
    LTEXT           "Height:",IDC_UD_HEIGHT_LBL,81,60,24,8,WS_DISABLED
    GROUPBOX        "Options",IDC_STATIC,7,90,213,25
    GROUPBOX        "Orientation",IDC_STATIC,7,7,104,22
END

IDD_CUSTOM_PROMPT_DIALOG DIALOG DISCARDABLE  0, 0, 232, 49
STYLE DS_MODALFRAME | WS_POPUP | WS_CAPTION | WS_SYSMENU
CAPTION "Custom"
FONT 8, "MS Sans Serif"
BEGIN
    EDITTEXT        IDC_PROMPT_TEXT,35,7,135,14,ES_AUTOHSCROLL
    DEFPUSHBUTTON   "OK",IDOK,175,7,50,14
    PUSHBUTTON      "Cancel",IDCANCEL,175,24,50,14
    LTEXT           "Custom:",IDC_STATIC,7,8,26,8
END

IDD_DIALOG_LINK_PROPERTIES DIALOG DISCARDABLE  0, 0, 262, 162
STYLE DS_MODALFRAME | WS_POPUP | WS_CAPTION | WS_SYSMENU
CAPTION "Link Properties"
FONT 8, "MS Sans Serif"
BEGIN
    GROUPBOX        " Link Text ",IDC_STATIC,7,7,248,52
    GROUPBOX        " Link Location ",IDC_STATIC,7,73,248,52
    LTEXT           "Enter &text to display for the link:",IDC_STATIC,16,20,
                    223,8
    EDITTEXT        IDC_EDIT_LINK_TEXT,16,34,232,14,ES_AUTOHSCROLL
    LTEXT           "Enter a web page &location:",IDC_STATIC,16,88,223,8
    EDITTEXT        IDC_EDIT_LINK_LOCATION,16,103,232,14,ES_AUTOHSCROLL
    DEFPUSHBUTTON   "OK",IDOK,69,140,50,14
    PUSHBUTTON      "Cancel",IDCANCEL,128,140,50,14
END

#ifndef _MAC
/////////////////////////////////////////////////////////////////////////////
//
// Version
//

VS_VERSION_INFO VERSIONINFO
 FILEVERSION 1,0,0,1
 PRODUCTVERSION 1,0,0,1
 FILEFLAGSMASK 0x3fL
#ifdef _DEBUG
 FILEFLAGS 0x1L
#else
 FILEFLAGS 0x0L
#endif
 FILEOS 0x4L
 FILETYPE 0x1L
 FILESUBTYPE 0x0L
BEGIN
    BLOCK "StringFileInfo"
    BEGIN
        BLOCK "040904B0"
        BEGIN
            VALUE "CompanyName", "\0"
            VALUE "FileDescription", "MfcEmbed MFC Application\0"
            VALUE "FileVersion", "1, 0, 0, 1\0"
            VALUE "InternalName", "MfcEmbed\0"
            VALUE "LegalCopyright", "Copyright (C) 2001\0"
            VALUE "LegalTrademarks", "\0"
            VALUE "OriginalFilename", "MfcEmbed.EXE\0"
            VALUE "ProductName", "MfcEmbed Application\0"
            VALUE "ProductVersion", "1, 0, 0, 1\0"
        END
    END
    BLOCK "VarFileInfo"
    BEGIN
        VALUE "Translation", 0x409, 1200
    END
END

#endif    // !_MAC


/////////////////////////////////////////////////////////////////////////////
//
// DESIGNINFO
//

#ifdef APSTUDIO_INVOKED
GUIDELINES DESIGNINFO DISCARDABLE 
BEGIN
    IDD_ABOUTBOX, DIALOG
    BEGIN
        LEFTMARGIN, 7
        RIGHTMARGIN, 228
        TOPMARGIN, 7
        BOTTOMMARGIN, 48
    END

    IDD_PROFILES, DIALOG
    BEGIN
        LEFTMARGIN, 7
        RIGHTMARGIN, 189
        TOPMARGIN, 7
        BOTTOMMARGIN, 88
    END

    IDD_PROFILE_NEW, DIALOG
    BEGIN
        LEFTMARGIN, 7
        RIGHTMARGIN, 170
        TOPMARGIN, 7
        BOTTOMMARGIN, 72
    END

    IDD_PROFILE_RENAME, DIALOG
    BEGIN
        LEFTMARGIN, 7
        RIGHTMARGIN, 170
        TOPMARGIN, 7
        BOTTOMMARGIN, 69
    END

    IDD_PRINTSETUP_DIALOG, DIALOG
    BEGIN
        LEFTMARGIN, 7
        RIGHTMARGIN, 321
        TOPMARGIN, 7
        BOTTOMMARGIN, 168
    END

    IDD_HEADERFOOTER_TAB, DIALOG
    BEGIN
        LEFTMARGIN, 7
        RIGHTMARGIN, 312
        TOPMARGIN, 7
        BOTTOMMARGIN, 99
    END

    IDD_FORMAT_OPTIONS_TAB, DIALOG
    BEGIN
        LEFTMARGIN, 7
        RIGHTMARGIN, 314
        TOPMARGIN, 7
        BOTTOMMARGIN, 119
    END

    IDD_CUSTOM_PROMPT_DIALOG, DIALOG
    BEGIN
        LEFTMARGIN, 7
        RIGHTMARGIN, 225
        TOPMARGIN, 7
        BOTTOMMARGIN, 42
    END
END
#endif    // APSTUDIO_INVOKED


/////////////////////////////////////////////////////////////////////////////
//
// String Table
//

STRINGTABLE PRELOAD DISCARDABLE 
BEGIN
    IDR_MAINFRAME           "mfcembed"
END

STRINGTABLE PRELOAD DISCARDABLE 
BEGIN
    IDS_NOSECURITY_INFO     "This page has no security information or was not encrypted.\nThis means it was possible for other people to view this page when it was loaded."
    IDS_ENCRYPTION_HIGH_GRADE "High-grade Encryption (%1% %2!d! bit)"
    IDS_ENCRYPTION_LOW_GRADE "Low-grade Encryption (%1% %2!d! bit)"
    IDS_ENCRYPTION_NONE     "Connection Not Encrypted"
    IDS_SRCH_STR_NOT_FOUND  "The text you entered was not found"
    IDS_VIEW_FRAME_SOURCE   "View Frame Source"
    IDS_OPEN_FRAME_IN_NEW_WINDOW "Open Frame in New Window"
END

STRINGTABLE PRELOAD DISCARDABLE 
BEGIN
    AFX_IDS_APP_TITLE       "mfcembed"
    AFX_IDS_IDLEMESSAGE     "Ready"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_APP_ABOUT            "Display program information, version number and copyright\nAbout"
    ID_APP_EXIT             "Quit the application; prompts to save documents\nExit"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_NEXT_PANE            "Switch to the next window pane\nNext Pane"
    ID_PREV_PANE            "Switch back to the previous window pane\nPrevious Pane"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_WINDOW_SPLIT         "Split the active window into panes\nSplit"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_EDIT_CLEAR           "Erase the selection\nErase"
    ID_EDIT_CLEAR_ALL       "Erase everything\nErase All"
    ID_EDIT_COPY            "Copy the selection and put it on the Clipboard\nCopy"
    ID_EDIT_CUT             "Cut the selection and put it on the Clipboard\nCut"
    ID_EDIT_FIND            "Find the specified text\nFind"
    ID_EDIT_PASTE           "Insert Clipboard contents\nPaste"
    ID_EDIT_REPEAT          "Repeat the last action\nRepeat"
    ID_EDIT_REPLACE         "Replace specific text with different text\nReplace"
    ID_EDIT_SELECT_ALL      "Select the entire document\nSelect All"
    ID_EDIT_UNDO            "Undo the last action\nUndo"
    ID_EDIT_REDO            "Redo the previously undone action\nRedo"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_VIEW_TOOLBAR         "Show or hide the toolbar\nToggle ToolBar"
    ID_VIEW_STATUS_BAR      "Show or hide the status bar\nToggle StatusBar"
END

STRINGTABLE DISCARDABLE 
BEGIN
    AFX_IDS_SCSIZE          "Change the window size"
    AFX_IDS_SCMOVE          "Change the window position"
    AFX_IDS_SCMINIMIZE      "Reduce the window to an icon"
    AFX_IDS_SCMAXIMIZE      "Enlarge the window to full size"
    AFX_IDS_SCNEXTWINDOW    "Switch to the next document window"
    AFX_IDS_SCPREVWINDOW    "Switch to the previous document window"
    AFX_IDS_SCCLOSE         "Close the active window and prompts to save the documents"
END

STRINGTABLE DISCARDABLE 
BEGIN
    AFX_IDS_SCRESTORE       "Restore the window to normal size"
    AFX_IDS_SCTASKLIST      "Activate Task List"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_EDIT_SELECT_NONE     "Select nothing in the document\nSelect None"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_FILE_PRINTPREVIEW    "Print Preview"
    ID_FILE_PRINTSETUP      "Page Setup Dialog"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_ARIAL                "Arial"
    ID_TIMES                "Times New Roman"
END

STRINGTABLE DISCARDABLE
BEGIN
    IDS_PROFILES_FOLDER_NAME "MfcEmbed"
    IDS_PROFILES_NONSHARED_NAME "Browser"
END

#endif    // English (U.S.) resources
/////////////////////////////////////////////////////////////////////////////



#ifndef APSTUDIO_INVOKED
/////////////////////////////////////////////////////////////////////////////
//
// Generated from the TEXTINCLUDE 3 resource.
//
#define _AFX_NO_SPLITTER_RESOURCES
#define _AFX_NO_OLE_RESOURCES
#define _AFX_NO_TRACKER_RESOURCES
#define _AFX_NO_PROPERTY_RESOURCES

#if !defined(AFX_RESOURCE_DLL) || defined(AFX_TARG_ENU)
#ifdef _WIN32
LANGUAGE 9, 1
#pragma code_page(1252)
#endif //_WIN32
#include "res\mfcembed.rc2"  // non-Microsoft Visual C++ edited resources
#include "afxres.rc"         // Standard components
#endif

/////////////////////////////////////////////////////////////////////////////
#endif    // not APSTUDIO_INVOKED

